@@ -90,7 +90,7 @@ GenTab::GenTab(QWidget* p) :
 #ifndef CRON_DILLON
         scronCbx->setChecked( g_Option->useSyscron );
 #endif
-        if ( System::getCommand( "anacron" ) == "" ) anacCbx->setEnabled( false );
+        if ( ! ( System::getAnacStatus() & ANAC_INSTALLED ) ) anacCbx->setEnabled( false );
       }
     }
 #ifndef CRON_DILLON
@@ -1397,11 +1397,7 @@ void ConfDlg::slotApply()
   // 'at' New Data Template
   g_Option->atNewCmnd = atTab->cmndTed->text();
   g_Option->atNewTime = atTab->delaySpb->value();
-  if ( atTab->monRbt->isChecked() ){
-    g_Option->atNewMail = true;
-  }else{
-    g_Option->atNewMail = false;
-  }
+  g_Option->atNewMail = atTab->monRbt->isChecked();
 
   if ( chgFlag & CHG_LIST ) chgFlag |= CHG_ELIST;
 
