@@ -142,7 +142,7 @@ void KronekoDoc::setView( KronekoView *v )
               SLOT( slotCronExecute() ) );
 
 //---------- anacEditWgt ----------
-  if ( System::isAnacWritable() ){
+  if ( System::getAnacStatus() & ANAC_WRITABLE ){
     connect( v->anacEditWgt->cmtTed,
               SIGNAL( textChanged() ), this,
               SLOT ( slotAnacCmntChanged() ) );
@@ -228,11 +228,10 @@ void KronekoDoc::timerEvent( QTimerEvent* )
     pStart( RUN_LIST_TIME );
   }else{
     if ( curView == VIEW_CLOCK ) view->clockWgt->dspCurTime();
-  }
 
-  // Play Sound
-  if ( g_Option->useSound ){
-    if ( sec == ( 60 - g_Option->soundSec ) ){
+    // Play Sound
+    if ( g_Option->useSound ){
+      if ( sec == ( 60 - g_Option->soundSec ) ){
         for ( QListViewItemIterator it( view->stngLvw ); it.current(); ++it ){
           TabLvi *c = (TabLvi*)it.current();
           if ( c->dType != ANACRON ){
@@ -244,6 +243,7 @@ void KronekoDoc::timerEvent( QTimerEvent* )
             }            
           }
         }
+      }
     }
   }
 }
@@ -510,9 +510,9 @@ void KronekoDoc::slotCronVarDlg()
     }
     e->varLvw->setVar(e->editCron->userTbl->Vars);
     e->editCron->userTbl->Flag |= EDIT_MODIFY;
+    bUpdate = true;
     view->stngLvw->resetFlag();
     view->execLvw->resetFlag();
-    getApp()->fileSave->setEnabled(true);
   }
 }
 
@@ -531,7 +531,7 @@ void KronekoDoc::slotCronModify()
   CronEditWgt *e = view->cronEditWgt;
 
   // Save Button Enable
-  getApp()->fileSave->setEnabled(true);
+  bUpdate = true;
 
   // Remove Editing Data
   bool nflg = false;
@@ -582,7 +582,7 @@ void KronekoDoc::slotCronCreate()
   }
 
   // Save Button Enable
-  getApp()->fileSave->setEnabled(true);
+  bUpdate = true;
 
   // New 'crontab' Table
   if ( curEditCron != NULL ){
@@ -610,7 +610,8 @@ void KronekoDoc::slotCronDelete()
 {
 
   // Save Button Enable
-  getApp()->fileSave->setEnabled(true);
+  bUpdate = true;
+  getApp()->fileSave->setEnabled( bUpdate );
 
   // Delete Flag ON
   curEditCron->Flag |= EDIT_DELETE;
@@ -714,7 +715,7 @@ void KronekoDoc::slotAnacVarDlg()
       return;
     }
     // Header
-    getApp()->fileSave->setEnabled(true);
+    bUpdate = true;
     e->editAnac->userTbl->Head = dlg.getHead();
     // Variables
     e->varLvw->clear();
@@ -747,7 +748,7 @@ void KronekoDoc::slotAnacModify()
   }
 
   // Save Button Enable
-  getApp()->fileSave->setEnabled(true);
+  bUpdate = true;
 
   // Remove Editing Data  
   AnacEditWgt *e = view->anacEditWgt;
@@ -786,7 +787,7 @@ void KronekoDoc::slotAnacCreate()
   }
 
   // Save Button Enable
-  getApp()->fileSave->setEnabled(true);
+  bUpdate = true;
 
   // Create 'anacron' Table
   if ( curEditAnac != NULL ){
@@ -822,9 +823,10 @@ void KronekoDoc::slotAnacDelete()
 {
 
   // Save Button Enable
-  getApp()->fileSave->setEnabled(true);
+  bUpdate = true;
 
   curEditAnac->Flag |= EDIT_DELETE;
+  getApp()->fileSave->setEnabled( bUpdate );
 
   // Set Button
   view->anacEditWgt->setButton( *curEditAnac );
@@ -935,7 +937,7 @@ void KronekoDoc::slotAtModify()
   if ( ! chkAt( view->atEditWgt->editAt ) ) return;
 
   // Save Button Enable
-  getApp()->fileSave->setEnabled(true);
+  bUpdate = true;
 
   AtEditWgt *e = view->atEditWgt;
   int flg = curEditAt->Flag;
@@ -963,7 +965,7 @@ void KronekoDoc::slotAtCreate()
   if ( ! chkAt( view->atEditWgt->editAt ) ) return;
 
   // Save Button Enable
-  getApp()->fileSave->setEnabled(true);
+  bUpdate = true;
 
 //  if ( curEditAt->Flag & EDIT_DELETE ){
   if ( curEditAt != NULL ){
@@ -998,7 +1000,8 @@ void KronekoDoc::slotAtDelete()
 {
 
   // Save Button Enable
-  getApp()->fileSave->setEnabled(true);
+  bUpdate = true;
+  getApp()->fileSave->setEnabled( bUpdate );
 
   curEditAt->Flag = EDIT_DELETE | EDIT_CURRENT;
   view->stngLvw->resetFlag();
