@@ -182,7 +182,7 @@ AtTbl::AtTbl( const QString& s )
 
 //
 // Constructor
-LogTbl::LogTbl( const QString &str, const QString &prog, const QDate& mt )
+LogTbl::LogTbl( const QString &str, DATATYPE dty, const QString &prog, const QDate& mt )
 {
 
   QRegExp reg( "\\s+" );
@@ -204,18 +204,16 @@ LogTbl::LogTbl( const QString &str, const QString &prog, const QDate& mt )
   
   // Get Log Type
   s = str.section( reg, 4 );
-  if ( Prog == "CROND" || Prog == "crond" || Prog == "crontab" ) {
-    dType = CRON_LOG;
+  dType = dty;
+  if ( dType == CRON_LOG ){
     User = QString(s.section( QRegExp( "[\\(\\)]"), 1, 1 ) );
     LogStr = s.section( ") ", 1 );
   }
-  else if ( Prog == "anacron" ) {
-    dType = ANACRON_LOG;
+  else if ( dType == ANACRON_LOG ) {
     User = "-";
     LogStr = s.section( "]: ", 1, 1 );
   }
-  else if ( Prog == "atd" ){
-    dType = AT_LOG;
+  else {        // if ( dType == AT_LOG ){
     LogStr = s.section( ": ", 1, 1 );
     User = "-";
   }
