@@ -91,6 +91,7 @@ KronekoDoc::KronekoDoc(QWidget *parent, const char *name)
 
   curList = LIST_NONE;
   curView = VIEW_NONE;
+  bUpdate = false;
 
   // Statistic Information
   cronUserNum = 0;
@@ -115,11 +116,13 @@ KronekoDoc::~KronekoDoc()
 void KronekoDoc::pStart( int rmode )
 {
 
+  int cur = runMode;
   // Set Run Mode
   runMode = runMode | rmode;
 
   // Wake Thread
-  s_waitCond.wakeAll();
+//  if( cur == 0 ) s_waitCond.wakeAll();
+  if( cur == 0 ) s_waitCond.wakeOne();
   
 }
 
@@ -127,11 +130,9 @@ void KronekoDoc::pStart( int rmode )
 // Set Progress Bar
 void KronekoDoc::dspProgress( double d )
 {
-  qApp->unlock();
   int p = int( 100.0 * d );
   if ( p < 0 ) p = 0;
   else if ( p > 100 ) p = 100;
-  qApp->lock();
   getApp()->slotProgressBar( p );
   qApp->unlock();
   qApp->lock();
@@ -142,7 +143,8 @@ void KronekoDoc::dspProgress( double d )
 void KronekoDoc::dspStatusMsg( const QString& s )
 {
   getApp()->slotStatusMsg( s );
-
+  qApp->unlock();
+  qApp->lock();
 }
 
 //
@@ -166,7 +168,7 @@ void KronekoDoc::run()
 
     if ( runMode & RUN_EXIT ) {
       // Exit
-      dspStatusMsg(i18n("Exiting."));
+      dspStatusMsg(i18n("Exiting..."));
       qApp->unlock();
       QApplication::exit();
       // Exit Thread
@@ -185,7 +187,7 @@ void KronekoDoc::run()
       view->clockWgt->clrClock();
       if ( ! g_ViewMode ){
         view->cronEditWgt->setEnabled( false );
-        if ( System::isAnacWritable() ) view->anacEditWgt->setEnabled( false );
+        if ( System::getAnacStatus() & ANAC_WRITABLE ) view->anacEditWgt->setEnabled( false );
         view->atEditWgt->setEnabled( false );
       }
       
@@ -772,33 +774,29 @@ void KronekoDoc::setLogView()
     QTextStream t( &f );        // use a text stream
     QString s;
     QString prog;
+    QString w;
+    DATATYPE dty;
     bool flg;
     while ( !t.eof() ) {        // until end of file...
       s = t.readLine();
       flg = false;
-      if ( s.find( "crontab[" ) > 0 ){
-        if ( s.find( ") LIST (" )  == -1 ) {
-          flg = true;
-          prog = "crontab";
-        }  
-      } else if ( s.find( "CROND[" ) > 0 ){
-          flg = true;
-          prog = "CROND";
-      } else if ( s.find( "crond[" ) > 0 ){
-          flg = true;
-          prog = "crond";
-      } else if ( s.find( "anacron[" ) > 0 ){
-          flg = true;
-          prog = "anacron";
-      } else if ( s.find( "cron[" ) > 0 ){
-          flg = true;
-          prog = "crond";
-      } else if ( s.find( "atd[" ) > 0 ){
-          flg = true;
-          prog = "atd";
+      w = s.left( s.find( '[' ) );
+      prog = w.section( ' ', -1, -1 );
+      if ( prog == "crontab" && s.find( ") LIST (" )  == -1 ) {
+        flg = true;
+        dty = CRON_LOG;
+      } else if ( prog == "CROND" || prog == "crond" || prog == "cron" ){
+        dty = CRON_LOG;
+        flg = true;
+      } else if ( prog == "anacron" ){
+        dty = ANACRON_LOG;
+        flg = true;
+      } else if ( prog == "atd" ){
+        dty = AT_LOG;
+        flg = true;
       }
       if ( flg ){
-        view->logLvw->addItem( new LogTbl( s, prog, mt.date() ) );
+        view->logLvw->addItem( new LogTbl( s, dty, prog, mt.date() ) );
         l++;
         if ( ( l % 50) == 0 ) {
           dspProgress( 0.2 + ( ( 0.8 / g_Option->logListMax ) * l ) );
@@ -923,13 +921,13 @@ void KronekoDoc::editTime()
         }
       }
       t->Next = CronTime(c).GetNextTime(*g_CurTime);
+      // Save Button Enable
+      bUpdate = true;      
       // Reset Execute List
       view->stngLvw->resetFlag();
       pStart( RUN_LIST_EXEC );
       view->clockWgt->clockView->iniFrame( true );
       dspView();
-      // Save Button Enable
-      getApp()->fileSave->setEnabled(true);
     }
   }else{
     //
@@ -952,13 +950,13 @@ void KronekoDoc::editTime()
         }
       }
       t->Next = a->Time;
+      // Save Button Enable
+      bUpdate = true;
       // Reset Execute List
       view->stngLvw->resetFlag();
       pStart( RUN_LIST_EXEC );
       view->clockWgt->clockView->iniFrame( true );
       dspView();
-      // Save Button Enable
-      getApp()->fileSave->setEnabled(true);
     }
   }
 
@@ -995,7 +993,7 @@ void KronekoDoc::editSelect()
     view->viewTab->showPage( view->cronEditWgt );
   }else if ( c->dType == ANACRON ){
     // Edit 'anacrontab' Data
-     if ( ! System::isAnacWritable() ) return;
+     if ( ! ( System::getAnacStatus() & ANAC_WRITABLE ) ) return;
     if ( curEditAnac ) {
       if ( view->anacEditWgt->creBtn->isEnabled() || view->anacEditWgt->modBtn->isEnabled() ){
         if ( QMessageBox::information( getApp(),
@@ -1821,7 +1819,7 @@ void KronekoDoc::dspView()
       if ( lvi->cronTbl()->Flag & NO_EXEDISP ) remFlag = false;
     }else if ( lvi->dType == ANACRON ){
       tflg = false;
-      if ( ! System::isAnacWritable() ) eflg = false;
+      if ( ! ( System::getAnacStatus() & ANAC_WRITABLE ) ) eflg = false;
       if ( lvi->anacTbl()->Flag & NO_EXEDISP ) remFlag = false;
     }else{
       if ( lvi->atTbl()->Flag & EDIT_DELETE ) tflg = false;
@@ -1846,7 +1844,7 @@ void KronekoDoc::dspView()
     QString h;
     int u_t=0;
     int e_t=0;
-    int s_t=0;
+//    int s_t=0;
     if ( lvi->dType == CRON ) {
       u = lvi->cronTbl()->User;
       h = "CRON(" + u + ")";
@@ -1855,13 +1853,13 @@ void KronekoDoc::dspView()
 #endif
       e_t = lvi->cronTbl()->exeCnt;
       u_t = lvi->cronTbl()->userTbl->itemCnt;
-      s_t = lvi->cronTbl()->userTbl->exeCnt;
+//      s_t = lvi->cronTbl()->userTbl->exeCnt;
     } else if ( lvi->dType == ANACRON ) {
       u = "-";
       h = "ANACRON";
       e_t = lvi->anacTbl()->exeCnt;
       u_t = lvi->anacTbl()->userTbl->itemCnt;
-      s_t = lvi->anacTbl()->userTbl->exeCnt;
+//      s_t = lvi->anacTbl()->userTbl->exeCnt;
     } else if ( lvi->dType == AT ) {
       u = lvi->atTbl()->User;
       h = "AT(" + u + ")";
@@ -1870,14 +1868,33 @@ void KronekoDoc::dspView()
         TabLvi *c = (TabLvi*)it.current();
         if ( c->dType == AT && c->atTbl()->User == u ) u_t++;
       }
-      for ( QListViewItemIterator it( view->execLvw ); it.current(); ++it ){
-        TabLvi *c = (TabLvi*)it.current();
-        if ( c->dType == AT && c->atTbl()->User == u ) s_t++;
+//      for ( QListViewItemIterator it( view->execLvw ); it.current(); ++it ){
+//        TabLvi *c = (TabLvi*)it.current();
+//        if ( c->dType == AT && c->atTbl()->User == u ) s_t++;
+//      }
+    }
+    getApp()->slotStatusMsgUser( h, u_t, e_t );
+    
+#ifndef CRON_DILLON
+  }else if ( log != NULL ){
+    int u_t=0;
+    for ( QListViewItemIterator it( view->logLvw ); it.current(); ++it ){
+      TabLvi *c = (TabLvi*)it.current();
+      if ( log->dType == CRON_LOG ){
+        if ( c->logTbl()->Prog == log->logTbl()->Prog &&
+             c->logTbl()->User == log->logTbl()->User ) u_t++;
+        
+      }else{
+        if ( c->dType == log->dType ) u_t++;
       }
     }
-    getApp()->slotStatusMsgUser( h, u_t, e_t, s_t );
-    
-    
+    QString h = log->logTbl()->Prog;
+    if ( log->dType == CRON_LOG ){
+        h = h + "(" + log->logTbl()->User + ")";
+    }
+    getApp()->slotStatusMsgUser( h, u_t, 0 );
+#endif    
   }
+  if ( ! g_ViewMode ) getApp()->fileSave->setEnabled( bUpdate );
     
 }
